RankIconData constructor

const RankIconData(
  1. int codePoint, {
  2. String fontFamily = iconFont,
  3. String fontPackage = iconFontPackage,
  4. bool matchTextDirection = false,
})

Creates a new RankIconData instance.

The codePoint parameter is the Unicode code point of the icon.

The fontFamily parameter is the font family of the icon.

The fontPackage parameter is the package name of the icon.

The matchTextDirection parameter is whether to match the text direction.

Implementation

const RankIconData(
  this.codePoint, {
  this.fontFamily = iconFont,
  this.fontPackage = iconFontPackage,
  this.matchTextDirection = false,
}) : super(codePoint);